import { getIconsCSSData } from '@iconify/utils/lib/css/icons';
import { loadIconSet } from './loader.mjs';
import { getIconNames } from './names.mjs';

function getCSSRulesForIcons(icons, options = {}) {
  const rules = /* @__PURE__ */ Object.create(null);
  const prefixes = getIconNames(icons);
  for (const prefix in prefixes) {
    const iconSet = loadIconSet(prefix, options);
    if (!iconSet) {
      throw new Error(
        `Cannot load icon set for "${prefix}". Install "@iconify-json/${prefix}" as dev dependency?`
      );
    }
    const generated = getIconsCSSData(
      iconSet,
      Array.from(prefixes[prefix]),
      options
    );
    const result = generated.common ? [generated.common, ...generated.css] : generated.css;
    result.forEach((item) => {
      const selector = Array.isArray(item.selector) ? item.selector.join(", ") : item.selector;
      rules[selector] = item.rules;
    });
  }
  return rules;
}

export { getCSSRulesForIcons };
