'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const icons = require('@iconify/utils/lib/css/icons');
const name = require('@iconify/utils/lib/icon/name');
const loader = require('./loader.cjs');

function transformCSSDataToRules(data, options = {}) {
  return {
    // Common rules
    ...options.overrideOnly || !data.common?.rules ? {} : data.common.rules,
    // Icon rules
    ...data.css[0].rules
  };
}
function getDynamicCSSRules(icon, options = {}) {
  const nameParts = icon.split(/--|:/);
  if (nameParts.length !== 2) {
    throw new Error(`Invalid icon name: "${icon}"`);
  }
  const [prefix, name$1] = nameParts;
  if (!(prefix.match(name.matchIconName) && name$1.match(name.matchIconName))) {
    throw new Error(`Invalid icon name: "${icon}"`);
  }
  const iconSet = loader.ensureLoadIconSet(prefix, options);
  const generated = icons.getIconsCSSData(iconSet, [name$1], {
    iconSelector: ".icon"
  });
  if (generated.css.length !== 1) {
    throw new Error(`Cannot find "${icon}". Bad icon name?`);
  }
  return transformCSSDataToRules(generated, options);
}

exports.getDynamicCSSRules = getDynamicCSSRules;
exports.transformCSSDataToRules = transformCSSDataToRules;
