'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const tools = require('@iconify/tools');
const pathe = require('pathe');
const iconSet = require('../helpers/icon-set.cjs');

function getLocalIconSets(options) {
  const { define: iconSetMaps } = options;
  return Object.keys(iconSetMaps).reduce((prev, current) => {
    const iconSetConfig = iconSetMaps[current];
    if (typeof iconSetConfig !== "string" && "iconifyJsonPath" in iconSetConfig) {
      const iconSet$1 = iconSet.loadIconifyJsonPath(iconSetConfig.iconifyJsonPath);
      if (iconSet$1) {
        return {
          ...prev,
          [current]: iconSet$1.export()
        };
      }
      return prev;
    }
    const _path = typeof iconSetConfig === "string" ? iconSetConfig : iconSetConfig.path;
    const options2 = typeof iconSetConfig === "string" ? void 0 : iconSetConfig.options;
    const preserveColors = typeof iconSetConfig === "string" ? void 0 : iconSetConfig.preserveColors;
    const customIconSet = tools.importDirectorySync(pathe.normalize(_path), options2);
    iconSet.optimizeIconSet(customIconSet, {
      preserveColors
    });
    return {
      ...prev,
      [current]: customIconSet.export()
    };
  }, {});
}

exports.getLocalIconSets = getLocalIconSets;
