import { importDirectorySync } from '@iconify/tools';
import pathe from 'pathe';
import { loadIconifyJsonPath, optimizeIconSet } from '../helpers/icon-set.mjs';

function getLocalIconSets(options) {
  const { define: iconSetMaps } = options;
  return Object.keys(iconSetMaps).reduce((prev, current) => {
    const iconSetConfig = iconSetMaps[current];
    if (typeof iconSetConfig !== "string" && "iconifyJsonPath" in iconSetConfig) {
      const iconSet = loadIconifyJsonPath(iconSetConfig.iconifyJsonPath);
      if (iconSet) {
        return {
          ...prev,
          [current]: iconSet.export()
        };
      }
      return prev;
    }
    const _path = typeof iconSetConfig === "string" ? iconSetConfig : iconSetConfig.path;
    const options2 = typeof iconSetConfig === "string" ? void 0 : iconSetConfig.options;
    const preserveColors = typeof iconSetConfig === "string" ? void 0 : iconSetConfig.preserveColors;
    const customIconSet = importDirectorySync(pathe.normalize(_path), options2);
    optimizeIconSet(customIconSet, {
      preserveColors
    });
    return {
      ...prev,
      [current]: customIconSet.export()
    };
  }, {});
}

export { getLocalIconSets };
