'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const node_fs = require('node:fs');
const node_module = require('node:module');

var _documentCurrentScript = typeof document !== 'undefined' ? document.currentScript : null;
const require$1 = node_module.createRequire((typeof document === 'undefined' ? require('u' + 'rl').pathToFileURL(__filename).href : (_documentCurrentScript && _documentCurrentScript.src || new URL('loader.cjs', document.baseURI).href)));
function locateIconSet(prefix) {
  try {
    const main = require$1.resolve(`@iconify-json/${prefix}/icons.json`);
    const info = require$1.resolve(`@iconify-json/${prefix}/info.json`);
    return {
      main,
      info
    };
  } catch {
  }
  try {
    const main = require$1.resolve(`@iconify/json/json/${prefix}.json`);
    return {
      main
    };
  } catch {
  }
}
const cache = /* @__PURE__ */ Object.create(null);
function loadIconSet(prefix, options) {
  let filename;
  const customIconSet = options.iconSets?.[prefix];
  if (customIconSet) {
    switch (typeof customIconSet) {
      case "function": {
        const result = customIconSet();
        if (options.iconSets) {
          options.iconSets[prefix] = result;
        }
        return result;
      }
      case "string": {
        filename = {
          main: customIconSet
        };
        break;
      }
      default:
        return customIconSet;
    }
  } else {
    filename = locateIconSet(prefix);
  }
  if (!filename) {
    return;
  }
  const main = typeof filename === "string" ? filename : filename.main;
  if (cache[main]) {
    return cache[main];
  }
  try {
    const result = JSON.parse(node_fs.readFileSync(main, "utf8"));
    if (!result.info && typeof filename === "object" && filename.info) {
      result.info = JSON.parse(node_fs.readFileSync(filename.info, "utf8"));
    }
    cache[main] = result;
    return result;
  } catch {
  }
}
function ensureLoadIconSet(prefix, options) {
  const iconSet = loadIconSet(prefix, options);
  if (!iconSet) {
    throw new Error(
      `Cannot load icon set for "${prefix}". Install "@iconify-json/${prefix}" as dev dependency?`
    );
  }
  return iconSet;
}

exports.ensureLoadIconSet = ensureLoadIconSet;
exports.loadIconSet = loadIconSet;
exports.locateIconSet = locateIconSet;
