import { readFileSync } from 'node:fs';
import { createRequire } from 'node:module';

const require = createRequire(import.meta.url);
function locateIconSet(prefix) {
  try {
    const main = require.resolve(`@iconify-json/${prefix}/icons.json`);
    const info = require.resolve(`@iconify-json/${prefix}/info.json`);
    return {
      main,
      info
    };
  } catch {
  }
  try {
    const main = require.resolve(`@iconify/json/json/${prefix}.json`);
    return {
      main
    };
  } catch {
  }
}
const cache = /* @__PURE__ */ Object.create(null);
function loadIconSet(prefix, options) {
  let filename;
  const customIconSet = options.iconSets?.[prefix];
  if (customIconSet) {
    switch (typeof customIconSet) {
      case "function": {
        const result = customIconSet();
        if (options.iconSets) {
          options.iconSets[prefix] = result;
        }
        return result;
      }
      case "string": {
        filename = {
          main: customIconSet
        };
        break;
      }
      default:
        return customIconSet;
    }
  } else {
    filename = locateIconSet(prefix);
  }
  if (!filename) {
    return;
  }
  const main = typeof filename === "string" ? filename : filename.main;
  if (cache[main]) {
    return cache[main];
  }
  try {
    const result = JSON.parse(readFileSync(main, "utf8"));
    if (!result.info && typeof filename === "object" && filename.info) {
      result.info = JSON.parse(readFileSync(filename.info, "utf8"));
    }
    cache[main] = result;
    return result;
  } catch {
  }
}
function ensureLoadIconSet(prefix, options) {
  const iconSet = loadIconSet(prefix, options);
  if (!iconSet) {
    throw new Error(
      `Cannot load icon set for "${prefix}". Install "@iconify-json/${prefix}" as dev dependency?`
    );
  }
  return iconSet;
}

export { ensureLoadIconSet, loadIconSet, locateIconSet };
