import plugin from 'tailwindcss/plugin';
import { getCSSRulesForIcons } from './clean.mjs';
import { getDynamicCSSRules } from './dynamic.mjs';
import { getIconSetIconStyles } from './helpers/icon-set.mjs';
export { optimizeIconSet } from './helpers/icon-set.mjs';

function addDynamicIconSelectors(options = {}) {
  const { prefix = "icon", preprocessSets = [], iconSets = {} } = options;
  let iconStyles = {};
  const mergedStaticIconNames = {
    // Load all icon styles for custom iconSets by default
    ...Object.keys(iconSets).reduce(
      (acc, iconSetName) => {
        return {
          ...acc,
          [iconSetName]: "*"
        };
      },
      {}
    ),
    ...Array.isArray(preprocessSets) ? preprocessSets.reduce(
      (acc, item) => {
        return {
          ...acc,
          [item]: "*"
        };
      },
      {}
    ) : preprocessSets
  };
  Object.keys(mergedStaticIconNames).forEach((iconSetName) => {
    const staticIconNames = mergedStaticIconNames[iconSetName];
    const iconSetIconStyles = getIconSetIconStyles(iconSetName, {
      pluginOptions: options,
      staticIconNames
    });
    iconStyles = {
      ...iconStyles,
      ...iconSetIconStyles
    };
  });
  return plugin(({ matchComponents }) => {
    matchComponents(
      {
        [prefix]: (icon) => {
          if (typeof icon === "string") {
            return getDynamicCSSRules(icon, options);
          }
          return icon;
        }
      },
      {
        values: iconStyles
      }
    );
  });
}
function addCleanIconSelectors(icons, options) {
  const rules = getCSSRulesForIcons(icons, options);
  return plugin(({ addUtilities }) => {
    addUtilities(rules);
  });
}

export { addCleanIconSelectors, addDynamicIconSelectors };
